/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.proton.engine.impl;

import org.apache.qpid.proton.engine.TransportException;
import org.apache.qpid.proton.framing.TransportFrame;

public interface FrameHandler
{
    /**
     * @throws IllegalStateException if I am not currently accepting input
     * @see #isHandlingFrames()
     * @returns false on end of stream
     */
    boolean handleFrame(TransportFrame frame);

    void closed(TransportException error);

    /**
     * Returns whether I am currently able to handle frames.
     * MUST be checked before calling {@link #handleFrame(TransportFrame)}.
     */
    boolean isHandlingFrames();

}
